# EmploymentEventType

codes for different kinds of employment/HR related events

URI: EmploymentEventType

## Permissible Values

| Value | Meaning | Description | Info |
| --- | --- | --- | --- |
| HIRE | bizcodes:001 | event for a new employee | |
| FIRE | bizcodes:002 | None | |
| PROMOTION | bizcodes:003 | promotion event | |
| TRANSFER | bizcodes:004 | transfer internally | |


## Identifier and Mapping Information


